@@ -1,16 +1,22 @@
 #ifndef KEXEC_ARCH_ARM_OPTIONS_H
 #define KEXEC_ARCH_ARM_OPTIONS_H
 
-#define OPT_ARCH_MAX   (OPT_MAX+0)
+#define OPT_DT_NO_OLD_ROOT	(OPT_MAX+0)
+#define OPT_ARCH_MAX		(OPT_MAX+1)
 
-#define OPT_APPEND	'a'
-#define OPT_RAMDISK	'r'
+#define OPT_DTB		(OPT_ARCH_MAX+0)
+#define OPT_ATAGS	(OPT_ARCH_MAX+1)
+#define OPT_IMAGE_SIZE	(OPT_ARCH_MAX+2)
+#define OPT_PAGE_OFFSET	(OPT_ARCH_MAX+3)
+#define OPT_APPEND	(OPT_ARCH_MAX+4)
+#define OPT_RAMDISK	(OPT_ARCH_MAX+5)
 
 /* Options relevant to the architecture (excluding loader-specific ones),
  * in this case none:
  */
 #define KEXEC_ARCH_OPTIONS \
 	KEXEC_OPTIONS \
+	{ "dt-no-old-root",	0, 0, OPT_DT_NO_OLD_ROOT }, \
 
 #define KEXEC_ARCH_OPT_STR KEXEC_OPT_STR ""
 
@@ -33,8 +39,14 @@
 	{ "command-line",	1, 0, OPT_APPEND },	\
 	{ "append",		1, 0, OPT_APPEND },	\
 	{ "initrd",		1, 0, OPT_RAMDISK },	\
-	{ "ramdisk",		1, 0, OPT_RAMDISK },
+	{ "ramdisk",		1, 0, OPT_RAMDISK },	\
+	{ "dtb",		1, 0, OPT_DTB }, 	\
+	{ "atags",		0, 0, OPT_ATAGS },	\
+	{ "image-size",		1, 0, OPT_IMAGE_SIZE }, \
+	{ "page-offset",	1, 0, OPT_PAGE_OFFSET },
 
-#define KEXEC_ALL_OPT_STR KEXEC_ARCH_OPT_STR "a:r:"
+#define KEXEC_ALL_OPT_STR KEXEC_ARCH_OPT_STR ""
+
+extern unsigned int kexec_arm_image_size;
 
 #endif /* KEXEC_ARCH_ARM_OPTIONS_H */
