@@ -14,10 +14,13 @@
 
 #include "kexec.h"
 
-#define CRASH_MAX_MEMORY_RANGES	32
+#define CRASH_MAX_MEMORY_RANGES	32768
+
+/* crash dump kernel support at most two regions, low_region and high region. */
+#define CRASH_MAX_RESERVED_RANGES	2
 
 extern struct memory_ranges usablemem_rgns;
-extern struct memory_range crash_reserved_mem;
+extern struct memory_range crash_reserved_mem[];
 extern struct memory_range elfcorehdr_mem;
 
 extern int load_crashdump_segments(struct kexec_info *info);
